@@ -3,7 +3,7 @@
 
 # maybe this module should be broken up into multiple files, or maybe not ...
 
-UA = "diffengine/0.2.2 (+https://github.com/docnow/diffengine)"
+UA = "diffengine/0.2.3 (+https://github.com/docnow/diffengine)"
 
 import os
 import re
@@ -215,7 +215,7 @@ class EntryVersion(BaseModel):
     summary = CharField()
     created = DateTimeField(default=datetime.utcnow)
     archive_url = CharField(null=True)
-    entry = ForeignKeyField(Entry, related_name='versions')
+    entry = ForeignKeyField(Entry, backref='versions')
 
     @property
     def diff(self):
@@ -250,7 +250,7 @@ class EntryVersion(BaseModel):
             resp = _get(save_url)
             wayback_id = resp.headers.get("Content-Location")
             if wayback_id:
-                self.archive_url = "https://wayback.archive.org" + wayback_id
+                self.archive_url = "https://web.archive.org" + wayback_id
                 logging.debug("archived version at %s", self.archive_url)
                 self.save()
                 return self.archive_url
@@ -263,8 +263,8 @@ class EntryVersion(BaseModel):
         return None
 
 class Diff(BaseModel):
-    old = ForeignKeyField(EntryVersion, related_name="prev_diffs")
-    new = ForeignKeyField(EntryVersion, related_name="next_diffs")
+    old = ForeignKeyField(EntryVersion, backref="prev_diffs")
+    new = ForeignKeyField(EntryVersion, backref="next_diffs")
     created = DateTimeField(default=datetime.utcnow)
     tweeted = DateTimeField(null=True)
     blogged = DateTimeField(null=True)
@@ -504,6 +504,8 @@ def main():
     logging.info("shutting down: new=%s checked=%s skipped=%s elapsed=%s", 
         new, checked, skipped, elapsed)
 
+    browser.quit()
+
 def _dt(d):
     return d.strftime("%Y-%m-%d %H:%M:%S")
 
